Official documentation for the project and all of its features is hosted at:

https://pantab.readthedocs.io/en/latest/index.html

Note that pantab is currently beta software. The API is experimental and subject to change.

